@@ -37,14 +37,14 @@ e_comp_cfdata_edd_init(E_Config_DD **conf_edd, E_Config_DD **match_edd)
    //E_CONFIG_VAL(D, T, max_unmapped_pixels, INT);
    E_CONFIG_VAL(D, T, max_unmapped_time, INT);
    E_CONFIG_VAL(D, T, min_unmapped_time, INT);
-   E_CONFIG_VAL(D, T, fps_average_range, INT);
    E_CONFIG_VAL(D, T, fps_corner, UCHAR);
    E_CONFIG_VAL(D, T, fps_show, UCHAR);
    E_CONFIG_VAL(D, T, indirect, UCHAR);
    E_CONFIG_VAL(D, T, texture_from_pixmap, UCHAR);
-   E_CONFIG_VAL(D, T, lock_fps, UCHAR);
+//   E_CONFIG_VAL(D, T, lock_fps, UCHAR);
    E_CONFIG_VAL(D, T, grab, UCHAR);
    E_CONFIG_VAL(D, T, vsync, UCHAR);
+   E_CONFIG_VAL(D, T, no_dither, UCHAR);
    E_CONFIG_VAL(D, T, swap_mode, UCHAR);
    //E_CONFIG_VAL(D, T, keep_unmapped, UCHAR);
    E_CONFIG_VAL(D, T, send_flush, UCHAR);
@@ -74,14 +74,14 @@ e_comp_cfdata_config_new(void)
    cfg->max_unmapped_pixels = 32 * 1024;  // implement
    cfg->max_unmapped_time = 10 * 3600; // implement
    cfg->min_unmapped_time = 5 * 60; // implement
-   cfg->fps_average_range = 30;
    cfg->fps_corner = 0;
    cfg->fps_show = 0;
    cfg->indirect = 0;
    cfg->texture_from_pixmap = 1;
-   cfg->lock_fps = 0;
+//   cfg->lock_fps = 0;
    cfg->grab = 0;
    cfg->vsync = 1;
+   cfg->no_dither = 0;
 #ifdef ECORE_EVAS_GL_X11_OPT_SWAP_MODE
    cfg->swap_mode = ECORE_EVAS_GL_X11_SWAP_MODE_AUTO;
 #else
