@@ -135,6 +135,7 @@ struct _E_Config
    double      winlist_list_size; // GUI
    double      winlist_large_size; // GUI
    Eina_Bool   winlist_list_no_miniatures; // GUI
+   Eina_Bool   no_state_hidden_desktop; // GUI
    int         maximize_policy; // GUI
    int         allow_manip; // GUI
    int         border_fix_on_shelf_toggle; // GUI
@@ -245,12 +246,15 @@ struct _E_Config
    int                       mouse_hand; //GUI
    double                    mouse_accel; // GUI
    int                       mouse_accel_threshold; // GUI
+   unsigned char             mouse_flat_accel; // GUI
    unsigned char             mouse_natural_scroll; // GUI
+   unsigned char             mouse_hires_scroll; // GUI
    unsigned char             mouse_emulate_middle_button; // GUI
 
    double                    touch_accel; // GUI
    unsigned char             touch_natural_scroll; // GUI
    unsigned char             touch_emulate_middle_button; // GUI
+   unsigned char             touch_flat_accel; // GUI
    unsigned char             touch_tap_to_click; // GUI
    unsigned char             touch_clickpad; // GUI
    unsigned char             touch_scrolling_2finger; // GUI
