@@ -28,6 +28,7 @@
 #include "e_place.h"
 #include "e_resist.h"
 #include "e_startup.h"
+#include "e_state.h"
 #include "e_signals.h"
 #include "e_xinerama.h"
 #include "e_layout.h"
@@ -155,6 +156,7 @@
 #include "e_comp_x_randr.h"
 #include "e_watchdog.h"
 #include "e_gesture.h"
+#include "e_sound.h"
 
 #ifdef HAVE_WAYLAND
 # include "e_comp_wl.h"
