@@ -90,6 +90,7 @@ e_randr2_init(void)
    E_CONFIG_LIST(D, T, screens, _e_randr2_cfg_screen_edd);
    E_CONFIG_VAL(D, T, hotplug_response, DOUBLE);
    E_CONFIG_VAL(D, T, restore, UCHAR);
+   E_CONFIG_VAL(D, T, use_cmd, UCHAR);
    E_CONFIG_VAL(D, T, ignore_hotplug_events, UCHAR);
    E_CONFIG_VAL(D, T, ignore_acpi_events, UCHAR);
    E_CONFIG_VAL(D, T, default_policy, UINT);
@@ -393,6 +394,7 @@ _config_load(void)
    cfg->version = E_RANDR_CONFIG_VERSION;
    cfg->screens = NULL;
    cfg->restore = 1;
+   cfg->use_cmd = 0;
    cfg->ignore_hotplug_events = 0;
    cfg->ignore_acpi_events = 0;
    cfg->default_policy = E_RANDR2_POLICY_EXTEND;
@@ -785,6 +787,7 @@ _screens_differ(E_Randr2 *r1, E_Randr2 *r2)
    return changed;
 }
 
+/*
 static Eina_Bool
 _cb_deferred_suspend_screen_change(void *data EINA_UNUSED)
 {
@@ -813,6 +816,7 @@ _cb_deferred_suspend_screen_change(void *data EINA_UNUSED)
      }
    return EINA_FALSE;
 }
+*/
 
 static Eina_Bool
 _cb_screen_change_delay(void *data EINA_UNUSED)
@@ -931,8 +935,9 @@ _cb_screen_change_delay(void *data EINA_UNUSED)
                   if ((e_config->screensaver_suspend_on_ac) ||
                       (e_powersave_mode_get() > E_POWERSAVE_MODE_LOW))
                     {
-                       printf("RRR: we should try and suspend now because on ac or suspend on ac is on\n");
-                       ecore_timer_add(1.0, _cb_deferred_suspend_screen_change, NULL);
+// disable for now.. moving to state system
+//                       printf("RRR: we should try and suspend now because on ac or suspend on ac is on\n");
+//                       ecore_timer_add(1.0, _cb_deferred_suspend_screen_change, NULL);
                     }
                }
           }
@@ -1164,7 +1169,7 @@ again:
              if (!common)
                {
                   modes = eina_list_remove_list(modes, l);
-                  // the list is no longer save to walk - so let's just
+                  // the list is no longer safe to walk - so let's just
                   // walk it again from scratch
                   goto again;
                }
@@ -1238,11 +1243,13 @@ _screen_config_do(E_Randr2_Screen *s)
    _config_do_recurse++;
    // find dependent clones and find a common config res
    cloneset = _screen_clones_find(e_randr2->screens, s);
+   printf("RRR: '%s' cloneset %p %i\n", s->info.name, cloneset, eina_list_count(cloneset));
    if (cloneset)
      {
         _screen_clones_common_sync(cloneset);
         eina_list_free(cloneset);
      }
+   printf("RRR: _screen_config_do 2\n");
    // if screen has a dependency...
    if ((s->config.relative.mode != E_RANDR2_RELATIVE_UNKNOWN) &&
        (s->config.relative.mode != E_RANDR2_RELATIVE_NONE) &&
@@ -1258,9 +1265,11 @@ _screen_config_do(E_Randr2_Screen *s)
              if (!s2->config.enabled) s2 = NULL;
           }
      }
+   printf("RRR: _screen_config_do 3\n");
    s->config.geom.x = 0;
    s->config.geom.y = 0;
    printf("RRR: screen config do %ix%i rotation=%i\n", s->config.mode.w, s->config.mode.h, s->config.rotation);
+   printf("RRR: _screen_config_do 4\n");
    if ((s->config.rotation == 0) || (s->config.rotation == 180))
      {
         s->config.geom.w = s->config.mode.w;
@@ -1273,6 +1282,7 @@ _screen_config_do(E_Randr2_Screen *s)
      }
    if (s2)
      {
+        printf("RRR: _screen_config_do 5\n");
         if (s->config.relative.mode == E_RANDR2_RELATIVE_CLONE)
           {
              printf("RRR: clone relative\n");
@@ -1321,6 +1331,7 @@ _screen_config_do(E_Randr2_Screen *s)
      }
    else
      {
+        printf("RRR: _screen_config_do 6\n");
         if ((s->config.relative.mode == E_RANDR2_RELATIVE_CLONE) &&
             (s->config.relative.to))
           {
