@@ -52,7 +52,6 @@ void *alloca (size_t);
 # include <dlfcn.h>
 # include <math.h>
 # include <fcntl.h>
-# include <fnmatch.h>
 # include <limits.h>
 # include <ctype.h>
 # include <time.h>
@@ -64,7 +63,6 @@ void *alloca (size_t);
 # include <signal.h>
 # include <inttypes.h>
 # include <assert.h>
-# include <fcntl.h>
 # if !defined (__FreeBSD__) && !defined (__OpenBSD__)
 #  ifdef HAVE_MALLOC_H
 #   include <malloc.h>
@@ -75,6 +73,11 @@ void *alloca (size_t);
 # include <sys/sysctl.h>
 #endif
 
+#if defined (__FreeBSD__) && (__FreeBSD__ > 12)
+# include <sys/ioctl.h>
+# include <sys/backlight.h>
+#endif
+
 # ifndef _POSIX_HOST_NAME_MAX
 #  define _POSIX_HOST_NAME_MAX 255
 # endif
