@@ -9,6 +9,8 @@ static E_Config_DD *conf_device_edd = NULL;
 static E_Config_DD *conf_edd = NULL;
 Config *ebluez5_config = NULL;
 
+static Ecore_Timer *zero_adapters_check_timer = NULL;
+
 E_API E_Module_Api e_modapi = {E_MODULE_API_VERSION, "Bluez5"};
 
 static void
@@ -33,96 +35,6 @@ _mod_icon_set(Evas_Object *base, Eina_Bool gadget)
 
 /////////////////////////////////////////////////////////////////////////////
 
-static void
-_gad_popup_dismiss(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
-{
-   Instance *inst = data;
-   E_FREE_FUNC(obj, evas_object_del);
-   inst->pop = NULL;
-}
-
-static void
-_gad_popup_del(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
-{
-   Instance *inst = data;
-   inst->pop = NULL;
-}
-
-static void
-_gad_popup_do(Instance *inst)
-{
-   Evas_Object *o;
-
-   if (inst->pop) return;
-
-   inst->pop = o = elm_ctxpopup_add(e_comp->elm);
-   elm_object_style_set(o, "noblock");
-   evas_object_smart_callback_add(o, "dismissed", _gad_popup_dismiss, inst);
-   evas_object_event_callback_add(o, EVAS_CALLBACK_DEL, _gad_popup_del, inst);
-
-   inst->popcontent = o = ebluez5_popup_content_add(e_comp->elm, inst);
-   elm_object_content_set(inst->pop, o);
-   evas_object_show(o);
-
-   e_gadget_util_ctxpopup_place(inst->o_bluez5, inst->pop, inst->o_bluez5);
-   evas_object_show(inst->pop);
-}
-
-static void
-_gad_mouse_up(void *data, Evas *evas EINA_UNUSED,
-              Evas_Object *obj EINA_UNUSED, void *event)
-{
-   Instance *inst = data;
-   Evas_Event_Mouse_Up *ev = event;
-
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return;
-   if (ev->button != 1) return;
-   if (!inst->pop) _gad_popup_do(inst);
-   else elm_ctxpopup_dismiss(inst->pop);
-}
-
-static void
-_gad_del(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
-{
-   Instance *inst = data;
-
-   instances = eina_list_remove(instances, inst);
-   E_FREE(inst);
-}
-
-/* XXX: fill in later when we have gotten this far
-static Evas_Object *
-_gad_config(Evas_Object *g EINA_UNUSED)
-{
-   if (e_configure_registry_exists("extensions/bluez5"))
-     e_configure_registry_call("extensions/bluez5", NULL, NULL);
-   return NULL;
-}
-*/
-
-static Evas_Object *
-_gad_create(Evas_Object *parent, int *id, E_Gadget_Site_Orient orient)
-{
-   Evas_Object *o;
-   Instance *inst = E_NEW(Instance, 1);
-
-   if (!inst) return NULL;
-   inst->id = *id;
-   inst->orient = orient;
-   inst->o_bluez5 = o = elm_layout_add(parent);
-   _mod_icon_set(o, EINA_TRUE);
-   evas_object_size_hint_aspect_set(o, EVAS_ASPECT_CONTROL_BOTH, 1, 1);
-// XXX: fill in later when we have gotten this far
-//   e_gadget_configure_cb_set(o, _gad_config);
-   evas_object_event_callback_add(o, EVAS_CALLBACK_MOUSE_UP, _gad_mouse_up, inst);
-   if (*id != -1)
-     evas_object_event_callback_add(o, EVAS_CALLBACK_DEL, _gad_del, inst);
-   instances = eina_list_append(instances, inst);
-   return o;
-}
-
-/////////////////////////////////////////////////////////////////////////////
-
 static void
 _popup_del(Instance *inst)
 {
@@ -179,6 +91,7 @@ _gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style)
    e_gadcon_client_util_menu_attach(inst->gcc);
    evas_object_event_callback_add(o, EVAS_CALLBACK_MOUSE_DOWN, _ebluez5_cb_mouse_down, inst);
    instances = eina_list_append(instances, inst);
+   ebluez5_instances_update();
    return inst->gcc;
 }
 
@@ -278,10 +191,6 @@ ebluez5_popups_show(void)
           {
              if (!inst->popup) _popup_new(inst);
           }
-        else
-          {
-             if (!inst->pop) _gad_popup_do(inst);
-          }
      }
 }
 
@@ -303,6 +212,48 @@ _cb_rfkill_unblock(void *datam EINA_UNUSED, const char *params)
         "users and groups there to be sure."));
 }
 
+static void
+_cb_rfkill_list(void *datam EINA_UNUSED, const char *params)
+{
+   if ((!params) || (!strcmp(params, "-"))) return;
+   // params is:
+   // hci0\tBluetooth\n
+   // phy0\tWireless LAN\n
+   // ...
+   // we got a list of possible rf-killable devices and this list callback
+   // will only have happened if we requested a list which we only do if
+   // tjhe list of adapters is empty still 5 seconds after init - something
+   // possibly wrong with them being blocked and thbus bluez not even listing
+   // them, so unblock them to get them listed
+   char **lines = eina_str_split(params, "\n", 0);
+   if (lines)
+     {
+        int i = 0;
+        char *line = lines[i];
+
+        while (line)
+          {
+             char **fields = eina_str_split(line, "\t", 0);
+             if (fields)
+               {
+                  if ((fields[0]) && (fields[1]))
+                    {
+                       if (!strcasecmp(fields[1], "bluetooth"))
+                         {
+                            ebluez5_rfkill_unblock(fields[0]);
+                         }
+                    }
+                  free(fields[0]);
+                  free(fields);
+               }
+             i++;
+             line = lines[i];
+          }
+        free(lines[0]);
+        free(lines);
+     }
+}
+
 void
 ebluez5_rfkill_unblock(const char *name)
 {
@@ -343,7 +294,7 @@ ebluez5_instances_update(void)
 static void
 _device_prop_clean(Config_Device *dev)
 {
-   if ((!dev->unlock) && (!dev->force_connect))
+   if (!dev->unlock)
      {
         ebluez5_config->devices = eina_list_remove(ebluez5_config->devices, dev);
         eina_stringshare_del(dev->addr);
@@ -381,27 +332,6 @@ ebluez5_device_prop_find(const char *address)
    return NULL;
 }
 
-
-void
-ebluez5_device_prop_force_connect_set(const char *address, Eina_Bool enable)
-{
-   Config_Device *dev;
-
-   if (!address) return;
-   dev = ebluez5_device_prop_find(address);
-   if (dev)
-     {
-        dev->force_connect = enable;
-        _device_prop_clean(dev);
-        return;
-     }
-   if (enable)
-     {
-        dev = _device_prop_new(address);
-        dev->force_connect = enable;
-     }
-}
-
 void
 ebluez5_device_prop_unlock_set(const char *address, Eina_Bool enable)
 {
@@ -422,6 +352,15 @@ ebluez5_device_prop_unlock_set(const char *address, Eina_Bool enable)
      }
 }
 
+static Eina_Bool
+_cb_zero_adapters_check(void *data EINA_UNUSED)
+{
+   zero_adapters_check_timer = NULL;
+   if (!ebluez5_popup_adapters_get())
+     e_system_send("rfkill-list", "-");
+   return EINA_FALSE;
+}
+
 /////////////////////////////////////////////////////////////////////////////
 
 /* Module Functions */
@@ -445,7 +384,6 @@ e_modapi_init(E_Module *m)
 #define T Config_Device
 #define D conf_device_edd
    E_CONFIG_VAL(D, T, addr, STR);
-   E_CONFIG_VAL(D, T, force_connect, UCHAR);
    E_CONFIG_VAL(D, T, unlock, UCHAR);
 
    conf_edd = E_CONFIG_DD_NEW("Config", Config);
@@ -457,6 +395,7 @@ e_modapi_init(E_Module *m)
    E_CONFIG_LIST(D, T, devices, conf_device_edd);
 
    e_system_handler_add("rfkill-unblock", _cb_rfkill_unblock, NULL);
+   e_system_handler_add("rfkill-list", _cb_rfkill_list, NULL);
 
    ebluez5_config = e_config_domain_load("module.ebluez5", conf_edd);
    if (!ebluez5_config) ebluez5_config = E_NEW(Config, 1);
@@ -465,7 +404,8 @@ e_modapi_init(E_Module *m)
    bz_init();
 
    e_gadcon_provider_register(&_gc_class);
-   e_gadget_type_add("Bluetooth", _gad_create, NULL);
+
+   zero_adapters_check_timer = ecore_timer_add(5.0, _cb_zero_adapters_check, NULL);
 
    return m;
 }
@@ -476,6 +416,13 @@ e_modapi_shutdown(E_Module *m EINA_UNUSED)
    Config_Adapter *ad;
    Config_Device *dev;
 
+   e_gadcon_provider_unregister(&_gc_class);
+   if (zero_adapters_check_timer)
+     {
+        ecore_timer_del(zero_adapters_check_timer);
+        zero_adapters_check_timer = NULL;
+     }
+   e_system_handler_del("rfkill-list", _cb_rfkill_list, NULL);
    e_system_handler_del("rfkill-unblock", _cb_rfkill_unblock, NULL);
    EINA_LIST_FREE(ebluez5_config->adapters, ad)
      {
@@ -493,9 +440,6 @@ e_modapi_shutdown(E_Module *m EINA_UNUSED)
    bz_shutdown();
    ebluze5_popup_shutdown();
 
-   e_gadget_type_del("Bluetooth");
-   e_gadcon_provider_unregister(&_gc_class);
-
    E_CONFIG_DD_FREE(conf_edd);
    E_CONFIG_DD_FREE(conf_adapter_edd);
    return 1;
