@@ -17,7 +17,7 @@ static void         _cb_bg_mouse_down(void *data, Evas *evas, Evas_Object *obj,
 
 struct _E_Config_Dialog_Data
 {
-   Evas_Object *lock_cmd_entry, *passwd_entry, *pin_entry;
+   Evas_Object *passwd_entry, *pin_entry;
    E_Config_Dialog *cfd, *bg_fsel;
 
    /* Common vars */
@@ -27,34 +27,28 @@ struct _E_Config_Dialog_Data
    /* Locking */
    int              start_locked;
    int              lock_on_suspend;
-   int              auto_lock;
    int              desklock_auth_method;
    int              login_zone;
    int              zone;
    char            *desklock_personal_passwd;
    char            *pin_str;
-   char            *custom_lock_cmd;
 
    /* Layout */
    const char     *desklock_layout;
 
    /* Timers */
    int              screensaver_lock;
-   double           idle_time;
    double           post_screensaver_time;
 
    /* Adv props */
    E_Desklock_Background_Method bg_method;
    int              bg_method_prev;
    Eina_List       *bgs;
-   int              ask_presentation;
-   double           ask_presentation_timeout;
 
    struct
    {
       Evas_Object *kbd_list;
       Evas_Object *loginbox_slider;
-      Evas_Object *auto_lock_slider;
       Evas_Object *o_table;
       Eina_List *bgs;
    } gui;
@@ -148,7 +142,7 @@ _fill_data(E_Config_Dialog_Data *cfdata)
    else if (!e_util_strcmp(bg->file, "user_background"))
      cfdata->bg_method = E_DESKLOCK_BACKGROUND_METHOD_WALLPAPER;
    else
-     cfdata->bg_method = E_DESKLOCK_BACKGROUND_METHOD_CUSTOM;
+     cfdata->bg_method = E_DESKLOCK_BACKGROUND_METHOD_THEME_DESKLOCK;
 
    cfdata->bg_method_prev = cfdata->bg_method;
 #ifndef HAVE_WAYLAND_ONLY
@@ -159,15 +153,10 @@ _fill_data(E_Config_Dialog_Data *cfdata)
      cfdata->use_xscreensaver = 1;
 
    cfdata->desklock_auth_method = e_config->desklock_auth_method;
-   if (e_config->desklock_custom_desklock_cmd)
-     cfdata->custom_lock_cmd = strdup(e_config->desklock_custom_desklock_cmd);
-
    cfdata->desklock_layout = e_config->xkb.desklock_layout;
    cfdata->start_locked = e_config->desklock_start_locked;
    cfdata->lock_on_suspend = e_config->desklock_on_suspend;
-   cfdata->auto_lock = e_config->desklock_autolock_idle;
    cfdata->screensaver_lock = e_config->desklock_autolock_screensaver;
-   cfdata->idle_time = e_config->desklock_autolock_idle_timeout / 60;
    cfdata->post_screensaver_time = e_config->desklock_post_screensaver_time;
    if (e_config->desklock_login_box_zone >= 0)
      {
@@ -179,10 +168,6 @@ _fill_data(E_Config_Dialog_Data *cfdata)
         cfdata->login_zone = e_config->desklock_login_box_zone;
         cfdata->zone = 0;
      }
-
-   cfdata->ask_presentation = e_config->desklock_ask_presentation;
-   cfdata->ask_presentation_timeout =
-     e_config->desklock_ask_presentation_timeout;
 }
 
 static void *
@@ -202,7 +187,6 @@ _free_data(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
    E_Config_Desklock_Background *bg;
    if (cfdata->bg_fsel)
      e_object_del(E_OBJECT(cfdata->bg_fsel));
-   E_FREE(cfdata->custom_lock_cmd);
    E_FREE(cfdata->desklock_personal_passwd);
    E_FREE(cfdata->pin_str);
    EINA_LIST_FREE(cfdata->bgs, bg)
@@ -213,12 +197,6 @@ _free_data(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
    free(cfdata);
 }
 
-static void
-_cb_lockscreen_gadgets()
-{
-   e_gadget_site_desklock_edit();
-}
-
 static Evas_Object *
 _basic_create(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cfdata)
 {
@@ -254,9 +232,6 @@ _basic_create(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cfdata)
    ow = e_widget_radio_add(evas, _("Use PIN (insecure)"), E_DESKLOCK_AUTH_METHOD_PIN, rg);
    evas_object_smart_callback_add(ow, "changed", _login_method_change, cfdata);
    e_widget_list_object_append(ol, ow, 1, 1, 0.5);
-   ow = e_widget_radio_add(evas, _("Use External Screenlock Command"), E_DESKLOCK_AUTH_METHOD_EXTERNAL, rg);
-   evas_object_smart_callback_add(ow, "changed", _login_method_change, cfdata);
-   e_widget_list_object_append(ol, ow, 1, 1, 0.5);
 
    of = e_widget_framelist_add(evas, _("Personal Screenlock Password (insecure)"), 0);
    cfdata->passwd_entry = ow = e_widget_entry_add(cfd->dia->win, &(cfdata->desklock_personal_passwd), NULL, NULL, NULL);
@@ -270,26 +245,16 @@ _basic_create(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cfdata)
    e_widget_framelist_object_append(of, ow);
    e_widget_list_object_append(ol, of, 1, 1, 0.5);
 
-   of = e_widget_framelist_add(evas, _("External Screenlock Command"), 0);
-   cfdata->lock_cmd_entry = ow = e_widget_entry_add(cfd->dia->win, &(cfdata->custom_lock_cmd), NULL, NULL, NULL);
-   e_widget_framelist_object_append(of, ow);
-
    e_widget_disabled_set(cfdata->passwd_entry,
      (cfdata->desklock_auth_method != E_DESKLOCK_AUTH_METHOD_PERSONAL));
    e_widget_disabled_set(cfdata->pin_entry,
      (cfdata->desklock_auth_method != E_DESKLOCK_AUTH_METHOD_PIN));
-   e_widget_disabled_set(cfdata->lock_cmd_entry,
-     (cfdata->desklock_auth_method != E_DESKLOCK_AUTH_METHOD_EXTERNAL));
 
-   e_widget_list_object_append(ol, of, 1, 1, 0.5);
-   ow = e_widget_button_add(evas, _("Configure Lockscreen Gadgets"), "configure", _cb_lockscreen_gadgets, NULL, NULL);
-
-   e_widget_list_object_append(ol, ow, 1, 1, 0.5);
    e_widget_toolbook_page_append(otb, NULL, _("Locking"), ol,
                                  1, 1, 1, 0, 0.0, 0.0);
 
    /* Keyboard Layout */
-   cfdata->gui.kbd_list = ol = e_widget_ilist_add(evas, 32 * e_scale, 32 * e_scale, &cfdata->desklock_layout);
+   cfdata->gui.kbd_list = ol = e_widget_ilist_add(evas, 40 * e_scale, 40 * e_scale, &cfdata->desklock_layout);
    EINA_LIST_FOREACH(e_config->xkb.used_layouts, l, cl)
      {
         Evas_Object *icon, *end;
@@ -324,7 +289,7 @@ _basic_create(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cfdata)
         grp++;
      }
    e_widget_toolbook_page_append(otb, NULL, _("Keyboard Layout"), ol,
-                                 1, 1, 1, 0, 0.0, 0.0);
+                                 1, 1, 1, 1, 0.0, 0.0);
 
    /* Login */
    ol = e_widget_list_add(evas, 0, 0);
@@ -354,7 +319,7 @@ _basic_create(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cfdata)
 
    /* Timers */
    ol = e_widget_list_add(evas, 0, 0);
-   oc = e_widget_check_add(evas, _("Lock after screensaver activates"),
+   oc = e_widget_check_add(evas, _("Lock after blanking"),
                            &cfdata->screensaver_lock);
    e_widget_disabled_set(oc, !cfdata->use_xscreensaver);
    e_widget_list_object_append(ol, oc, 1, 1, 0.5);
@@ -366,29 +331,9 @@ _basic_create(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cfdata)
      e_widget_check_widget_disable_on_unchecked_add(oc, ow);
    e_widget_list_object_append(ol, ow, 1, 1, 0.5);
 
-   oc = e_widget_check_add(evas, _("Lock when idle time exceeded"),
-                           &cfdata->auto_lock);
-   e_widget_list_object_append(ol, oc, 1, 1, 0.5);
-
-   ow = e_widget_slider_add(evas, 1, 0, _("%1.0f minutes"), 1.0, 90.0, 1.0, 0,
-                            &(cfdata->idle_time), NULL, 100);
-   e_widget_check_widget_disable_on_unchecked_add(oc, ow);
-   e_widget_list_object_append(ol, ow, 1, 1, 0.5);
    e_widget_toolbook_page_append(otb, NULL, _("Timers"), ol,
                                  1, 1, 1, 0, 0.0, 0.0);
 
-   /* Presentation */
-   ol = e_widget_list_add(evas, 0, 0);
-   oc = e_widget_check_add(evas, _("Suggest if deactivated before"),
-                           &(cfdata->ask_presentation));
-   e_widget_list_object_append(ol, oc, 1, 1, 0.5);
-   ow = e_widget_slider_add(evas, 1, 0, _("%1.0f seconds"), 1.0, 300.0, 10.0, 0,
-                            &(cfdata->ask_presentation_timeout), NULL, 100);
-   e_widget_check_widget_disable_on_unchecked_add(oc, ow);
-   e_widget_list_object_append(ol, ow, 1, 1, 0.5);
-   e_widget_toolbook_page_append(otb, NULL, _("Presentation Mode"), ol,
-                                 1, 1, 1, 0, 0.0, 0.0);
-
    /* Wallpapers */
    ol = e_widget_list_add(evas, 0, 0);
    of = e_widget_table_add(e_win_evas_win_get(evas), 1);
@@ -470,12 +415,8 @@ _basic_apply(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
      }
    e_config->desklock_start_locked = cfdata->start_locked;
    e_config->desklock_on_suspend = cfdata->lock_on_suspend;
-   e_config->desklock_autolock_idle = cfdata->auto_lock;
    e_config->desklock_post_screensaver_time = cfdata->post_screensaver_time;
    e_config->desklock_autolock_screensaver = cfdata->screensaver_lock;
-   e_config->desklock_autolock_idle_timeout = (cfdata->idle_time * 60);
-   e_config->desklock_ask_presentation = cfdata->ask_presentation;
-   e_config->desklock_ask_presentation_timeout = cfdata->ask_presentation_timeout;
    if (e_config->xkb.desklock_layout != cfdata->desklock_layout)
      {
         e_config->xkb.desklock_layout = eina_stringshare_ref(cfdata->desklock_layout);
@@ -513,10 +454,6 @@ _basic_apply(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
    else
      e_config->desklock_login_box_zone = cfdata->zone;
 
-   if (cfdata->custom_lock_cmd)
-     eina_stringshare_replace(&e_config->desklock_custom_desklock_cmd,
-                              cfdata->custom_lock_cmd);
-
    cfdata->bg_method_prev = cfdata->bg_method;
    e_config_save_queue();
    return 1;
@@ -530,16 +467,10 @@ _basic_check_changed(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfd
 
    if (e_config->xkb.desklock_layout != cfdata->desklock_layout)
      return 1;
-
    if (e_config->desklock_start_locked != cfdata->start_locked)
      return 1;
-
    if (e_config->desklock_on_suspend != cfdata->lock_on_suspend)
      return 1;
-
-   if (e_config->desklock_autolock_idle != cfdata->auto_lock)
-     return 1;
-
    if (e_config->desklock_auth_method != cfdata->desklock_auth_method)
      return 1;
    if (e_config->desklock_auth_method == E_DESKLOCK_AUTH_METHOD_PERSONAL)
@@ -567,13 +498,9 @@ _basic_check_changed(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfd
 
    if (e_config->desklock_autolock_screensaver != cfdata->screensaver_lock)
      return 1;
-
    if (!EINA_DBL_EQ(e_config->desklock_post_screensaver_time, cfdata->post_screensaver_time))
      return 1;
 
-   if (!EINA_DBL_EQ(e_config->desklock_autolock_idle_timeout, cfdata->idle_time * 60))
-     return 1;
-
    if (cfdata->bg_method_prev != (int)cfdata->bg_method) return 1;
    ll = cfdata->bgs;
    EINA_LIST_FOREACH(e_config->desklock_backgrounds, l, cbg)
@@ -596,16 +523,7 @@ _basic_check_changed(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfd
           return 1;
      }
 
-   if (e_config->desklock_custom_desklock_cmd && cfdata->custom_lock_cmd)
-     {
-        if (strcmp(e_config->desklock_custom_desklock_cmd, cfdata->custom_lock_cmd) != 0)
-          return 1;
-     }
-   else if (e_config->desklock_custom_desklock_cmd != cfdata->custom_lock_cmd)
-     return 1;
-
-   return (e_config->desklock_ask_presentation != cfdata->ask_presentation) ||
-          (!EINA_DBL_EQ(e_config->desklock_ask_presentation_timeout, cfdata->ask_presentation_timeout));
+   return 0;
 }
 
 static void
@@ -754,13 +672,6 @@ _login_method_change(void *data, Evas_Object *obj EINA_UNUSED, void *event_info
         e_widget_entry_select_all(cfdata->pin_entry);
         e_widget_focus_set(cfdata->pin_entry, 1);
      }
-   e_widget_disabled_set(cfdata->lock_cmd_entry,
-     (cfdata->desklock_auth_method != E_DESKLOCK_AUTH_METHOD_EXTERNAL));
-   if (!e_widget_disabled_get(cfdata->lock_cmd_entry))
-     {
-        e_widget_entry_select_all(cfdata->lock_cmd_entry);
-        e_widget_focus_set(cfdata->lock_cmd_entry, 1);
-     }
 }
 
 static void
