@@ -140,7 +140,7 @@ const E_Intl_Pair basic_language_predefined_pairs[] = {
    {"sl_SI.UTF-8", "si_flag.png", "Slovenščina"},
    {"sv_SE.UTF-8", "se_flag.png", "Svenska"},
    {"tr_TR.UTF-8", "tr_flag.png", "Türkçe"},
-   {"uk_UK.UTF-8", "ua_flag.png", "Українська мова"},
+   {"uk_UA.UTF-8", "ua_flag.png", "Українська мова"},
    {"vi_VN UTF-8", "vn_flag.png", "Tiếng Việt"},
    {"zh_CN.UTF-8", "cn_flag.png", "中文 (简体)"},
    {"zh_TW.UTF-8", "tw_flag.png", "中文 (繁體)"},
@@ -649,11 +649,7 @@ _fill_data(E_Config_Dialog_Data *cfdata)
    e_lang_list = e_intl_language_list();
 
    /* Get list of all locales and start making map */
-#ifdef __OpenBSD__
-   output = popen("ls /usr/share/locale", "r");
-#else
    output = popen("locale -a", "r");
-#endif
    if ( output )
      {
         char line[32];
