@@ -24,7 +24,6 @@ e_int_config_cpufreq_module(Evas_Object *parent EINA_UNUSED, const char *params
 {
    E_Config_Dialog *cfd;
    E_Config_Dialog_View *v;
-   char buf[PATH_MAX];
 
    v = E_NEW(E_Config_Dialog_View, 1);
    v->create_cfdata = _create_data;
@@ -33,11 +32,9 @@ e_int_config_cpufreq_module(Evas_Object *parent EINA_UNUSED, const char *params
    v->basic.create_widgets = _basic_create_widgets;
    v->basic.check_changed = _basic_check_changed;
 
-   snprintf(buf, sizeof(buf), "%s/e-module-cpufreq.edj",
-            e_module_dir_get(cpufreq_config->module));
    cfd = e_config_dialog_new(NULL, _("Cpu Frequency Control Settings"),
                              "E", "_e_mod_cpufreq_config_dialog",
-                             buf, 0, v, NULL);
+                             "preferences-cpu-speed", 0, v, NULL);
    cpufreq_config->config_dialog = cfd;
    return cfd;
 }
