@@ -2,7 +2,6 @@
 #include "e_mod_main.h"
 #include "e_mod_packagekit.h"
 
-
 /* GUI */
 void
 packagekit_icon_update(E_PackageKit_Module_Context *ctxt,
@@ -38,6 +37,7 @@ packagekit_icon_update(E_PackageKit_Module_Context *ctxt,
                      count++;
                      break;
                   default:
+                     count++;
                      break;
                }
           }
@@ -165,10 +165,10 @@ _help_button_cb(void *data, Evas_Object *obj EINA_UNUSED,
 
    // update title label
    if (inst->ctxt->v_maj != -1)
-     snprintf(buf, sizeof(buf), "PackageKit version: %d.%d.%d",
+     snprintf(buf, sizeof(buf), "PackageKit %d.%d.%d",
               inst->ctxt->v_maj, inst->ctxt->v_min, inst->ctxt->v_mic);
    else
-     snprintf(buf, sizeof(buf), _("Unknown PackageKit version"));
+     snprintf(buf, sizeof(buf), _("Unknown PackageKit"));
    elm_object_text_set(inst->popup_title_entry, buf);
 }
 
@@ -291,13 +291,13 @@ packagekit_popup_update(E_PackageKit_Instance *inst, Eina_Bool rebuild_list)
    else if ((selected == NULL) || (eina_list_count(selected) == 0))
      {
         elm_object_text_set(inst->popup_install_button,
-                           _("Install all available updates"));
+                           _("Install updates"));
         elm_object_disabled_set(inst->popup_install_button, EINA_FALSE);
      }
    else if (eina_list_count(selected) > 0)
      {
-        snprintf(buf, sizeof(buf), P_("Install the selected update",
-                                      "Install %d selected updates",
+        snprintf(buf, sizeof(buf), P_("Install update",
+                                      "Install %d updates",
                                       eina_list_count(selected)),
                                       eina_list_count(selected));
         elm_object_text_set(inst->popup_install_button, buf);
@@ -357,15 +357,15 @@ _gl_item_double_text_get(void *data, Evas_Object *obj EINA_UNUSED, const char *p
    E_PackageKit_Package *pkg = data;
 
    if (!strcmp(part, "elm.text"))
-     {
-        return strdup(pkg->summary);
-     }
-   else
      {
         char *s = malloc(strlen(pkg->name) + strlen(pkg->version) + 2);
         sprintf(s, "%s %s", pkg->name, pkg->version);
         return s;
      }
+   else
+     {
+        return strdup(pkg->summary);
+     }
 
    return NULL;
 }
@@ -433,41 +433,34 @@ _genlist_selunsel_cb(void *data, Evas_Object *obj EINA_UNUSED,
 }
 
 static void
-_ctxpopup_dismissed(void *data, Evas_Object *obj, void *info EINA_UNUSED)
+_popup_autoclose_cb(void *data, Evas_Object *obj EINA_UNUSED)
 {
-   E_PackageKit_Instance *inst = data;
-
-   evas_object_del(obj);
-   inst->ctxpopup = NULL;
+   packagekit_popup_del(data);
 }
 
 void
-packagekit_popup_new(E_PackageKit_Instance *inst, Eina_Bool is_gadcon)
+packagekit_popup_new(E_PackageKit_Instance *inst)
 {
    Evas_Object *table, *bt, *ic, *lb, *li, *pb, *fr, *bx, *size_rect;
    const char *p;
 
-   if (is_gadcon)
-     {
-        inst->popup = e_gadcon_popup_new(inst->gcc, EINA_FALSE);
-        table = elm_table_add(e_comp->elm);
-     }
-   else
-     {
-        inst->ctxpopup = elm_ctxpopup_add(e_comp->elm);
-        elm_object_style_set(inst->ctxpopup, "noblock");
-        evas_object_smart_callback_add(inst->ctxpopup, "dismissed",
-                                       _ctxpopup_dismissed, inst);
-        table = elm_table_add(inst->ctxpopup);
-     }
+   inst->popup = e_gadcon_popup_new(inst->gcc, EINA_FALSE);
+   table = elm_table_add(e_comp->elm);
    evas_object_show(table);
 
+   fr = elm_frame_add(table);
+   elm_object_style_set(fr, "pad_large");
+   evas_object_size_hint_expand_set(fr, EVAS_HINT_EXPAND, 0.0);
+   evas_object_size_hint_fill_set(fr, EVAS_HINT_FILL, 0.0);
+   elm_table_pack(table, fr, 0, 0, 1, 1);
+   evas_object_show(fr);
+
    // horiz box for title and buttons
    bx = elm_box_add(table);
    elm_box_horizontal_set(bx, EINA_TRUE);
    evas_object_size_hint_expand_set(bx, EVAS_HINT_EXPAND, 0.0);
    evas_object_size_hint_fill_set(bx, EVAS_HINT_FILL, 0.0);
-   elm_table_pack(table, bx, 0, 0, 1, 1);
+   elm_object_content_set(fr, bx);
    evas_object_show(bx);
 
    // title label
@@ -481,8 +474,8 @@ packagekit_popup_new(E_PackageKit_Instance *inst, Eina_Bool is_gadcon)
 
    // refresh button
    ic = elm_icon_add(table);
-   evas_object_size_hint_min_set(ic, 16 * elm_config_scale_get(),
-                                     16 * elm_config_scale_get());
+   evas_object_size_hint_min_set(ic, 20 * elm_config_scale_get(),
+                                     20 * elm_config_scale_get());
    elm_icon_standard_set(ic, "view-refresh");
    bt = elm_button_add(table);
    elm_object_content_set(bt, ic);
@@ -492,8 +485,8 @@ packagekit_popup_new(E_PackageKit_Instance *inst, Eina_Bool is_gadcon)
 
    // help button
    ic = elm_icon_add(table);
-   evas_object_size_hint_min_set(ic, 16 * elm_config_scale_get(),
-                                     16 * elm_config_scale_get());
+   evas_object_size_hint_min_set(ic, 20 * elm_config_scale_get(),
+                                     20 * elm_config_scale_get());
    elm_icon_standard_set(ic, "help-contents");
    bt = elm_button_add(table);
    elm_object_content_set(bt, ic);
@@ -503,8 +496,8 @@ packagekit_popup_new(E_PackageKit_Instance *inst, Eina_Bool is_gadcon)
 
    // central area (sizer)
    size_rect = evas_object_rectangle_add(evas_object_evas_get(table));
-   evas_object_size_hint_min_set(size_rect, 300 * elm_config_scale_get(),
-                                            300 * elm_config_scale_get());
+   evas_object_size_hint_min_set(size_rect, 240 * elm_config_scale_get(),
+                                            240 * elm_config_scale_get());
    elm_table_pack(table, size_rect, 0, 1, 1, 1);
 
    // central area (error label)
@@ -553,11 +546,27 @@ packagekit_popup_new(E_PackageKit_Instance *inst, Eina_Bool is_gadcon)
    E_FILL(pb);
    elm_object_content_set(fr, pb);
 
+   fr = elm_frame_add(table);
+   elm_object_style_set(fr, "pad_large");
+   evas_object_size_hint_expand_set(fr, EVAS_HINT_EXPAND, 0.0);
+   evas_object_size_hint_fill_set(fr, EVAS_HINT_FILL, 0.0);
+   elm_table_pack(table, fr, 0, 2, 1, 1);
+   evas_object_show(fr);
+
+   // horiz box for title and buttons
+   bx = elm_box_add(table);
+   elm_box_horizontal_set(bx, EINA_TRUE);
+   elm_box_homogeneous_set(bx, EINA_TRUE);
+   evas_object_size_hint_expand_set(bx, EVAS_HINT_EXPAND, 0.0);
+   evas_object_size_hint_fill_set(bx, EVAS_HINT_FILL, 0.0);
+   elm_object_content_set(fr, bx);
+   evas_object_show(bx);
+
    // install button
    bt = inst->popup_install_button = elm_button_add(table);
    evas_object_size_hint_fill_set(bt, EVAS_HINT_FILL, 0.0);
    evas_object_smart_callback_add(bt, "clicked", _install_button_cb, inst);
-   elm_table_pack(table, bt, 0, 2, 1, 1);
+   elm_box_pack_end(bx, bt);
    evas_object_show(bt);
 
    // run package manager button (only if configured)
@@ -566,26 +575,19 @@ packagekit_popup_new(E_PackageKit_Instance *inst, Eina_Bool is_gadcon)
      {
         bt = elm_button_add(table);
         evas_object_size_hint_fill_set(bt, EVAS_HINT_FILL, 0.0);
-        elm_object_text_set(bt, _("Run the package manager"));
+        elm_object_text_set(bt, _("Manage packages"));
         evas_object_smart_callback_add(bt, "clicked", _run_button_cb, inst);
-        elm_table_pack(table, bt, 0, 3, 1, 1);
+        elm_box_pack_end(bx, bt);
         evas_object_show(bt);
      }
 
    // setup and show the popup
-   if (is_gadcon)
-     {
-        e_gadcon_popup_content_set(inst->popup, table);
-        e_object_data_set(E_OBJECT(inst->popup), inst);
-        E_OBJECT_DEL_SET(inst->popup, _popup_del_cb);
-        e_gadcon_popup_show(inst->popup);
-     }
-   else
-     {
-        elm_object_content_set(inst->ctxpopup, table);
-        e_gadget_util_ctxpopup_place(inst->gadget, inst->ctxpopup, NULL);
-        evas_object_show(inst->ctxpopup);
-     }
+   e_gadcon_popup_content_set(inst->popup, table);
+   e_object_data_set(E_OBJECT(inst->popup), inst);
+   E_OBJECT_DEL_SET(inst->popup, _popup_del_cb);
+   e_comp_object_util_autoclose(inst->popup->comp_object,
+                                _popup_autoclose_cb, NULL, inst);
+   e_gadcon_popup_show(inst->popup);
 
    // update the popup state and contents
    packagekit_popup_update(inst, EINA_TRUE);
@@ -596,8 +598,6 @@ packagekit_popup_del(E_PackageKit_Instance *inst)
 {
    if (inst->popup)
      E_FREE_FUNC(inst->popup, e_object_del);
-   if (inst->ctxpopup)
-     elm_ctxpopup_dismiss(inst->ctxpopup);
 
    inst->popup_genlist = inst->popup_title_entry = NULL;
    inst->popup_progressbar = inst->popup_progressbar_frame = NULL;
