@@ -50,16 +50,8 @@ static Config *temperature_config = NULL;
 static void
 _temperature_thread_free(Tempthread *tth)
 {
-#if defined(HAVE_EEZE)
-   const char *s;
-#endif
    eina_stringshare_del(tth->sensor_name);
-   eina_stringshare_del(tth->sensor_path);
-#if defined(HAVE_EEZE)
-   EINA_LIST_FREE(tth->tempdevs, s) eina_stringshare_del(s);
-#endif
-   e_powersave_sleeper_free(tth->sleeper);
-   free(tth->extn);
+   if (tth->sleeper) e_powersave_sleeper_free(tth->sleeper);
    free(tth);
 }
 
@@ -114,18 +106,6 @@ _temperature_apply(Config_Face *inst, int temp)
      }
 }
 
-#ifdef HAVE_EEZE
-static Eina_Bool
-_temperature_udev_poll(void *data)
-{
-   Tempthread *tth = data;
-   int temp = temperature_udev_get(tth);
-
-   _temperature_apply(tth->inst, temp);
-   return EINA_TRUE;
-}
-#endif
-
 static E_Gadcon_Client *
 _gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style)
 {
@@ -141,13 +121,9 @@ _gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style)
         inst->poll_interval = 128;
         inst->low = 30;
         inst->high = 80;
-        inst->sensor_type = SENSOR_TYPE_NONE;
         inst->sensor_name = NULL;
         inst->temp = -900;
         inst->units = CELSIUS;
-#ifdef HAVE_EEZE
-        inst->backend = UDEV;
-#endif
         if (!temperature_config->faces)
           temperature_config->faces = eina_hash_string_superfast_new(NULL);
         eina_hash_direct_add(temperature_config->faces, inst->id, inst);
@@ -157,9 +133,6 @@ _gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style)
    E_CONFIG_LIMIT(inst->low, 0, 100);
    E_CONFIG_LIMIT(inst->high, 0, 220);
    E_CONFIG_LIMIT(inst->units, CELSIUS, FAHRENHEIT);
-#ifdef HAVE_EEZE
-   E_CONFIG_LIMIT(inst->backend, TEMPGET, UDEV);
-#endif
 
    o = edje_object_add(gc->evas);
    e_theme_edje_object_set(o, "base/theme/modules/temperature",
@@ -231,12 +204,8 @@ _gc_id_new(const E_Gadcon_Client_Class *client_class EINA_UNUSED)
    inst->poll_interval = 128;
    inst->low = 30;
    inst->high = 80;
-   inst->sensor_type = SENSOR_TYPE_NONE;
    inst->sensor_name = NULL;
    inst->units = CELSIUS;
-#ifdef HAVE_EEZE
-   inst->backend = TEMPGET;
-#endif
    if (!temperature_config->faces)
      temperature_config->faces = eina_hash_string_superfast_new(NULL);
    eina_hash_direct_add(temperature_config->faces, inst->id, inst);
@@ -293,13 +262,6 @@ _temperature_face_shutdown(const Eina_Hash *hash EINA_UNUSED, const void *key EI
    if (inst->th) ecore_thread_cancel(inst->th);
    if (inst->sensor_name) eina_stringshare_del(inst->sensor_name);
    if (inst->id) eina_stringshare_del(inst->id);
-#ifdef HAVE_EEZE
-   if (inst->poller)
-     {
-        ecore_poller_del(inst->poller);
-        _temperature_thread_free(inst->tth);
-     }
-#endif
    E_FREE(inst);
    return EINA_TRUE;
 }
@@ -330,8 +292,8 @@ _temperature_check_main(void *data, Ecore_Thread *th)
         temp = temperature_tempget_get(tth);
         if (ptemp != temp) ecore_thread_feedback(th, (void *)((long)temp));
         ptemp = temp;
-        e_powersave_sleeper_sleep(tth->sleeper, tth->poll_interval);
         if (ecore_thread_check(th)) break;
+        e_powersave_sleeper_sleep(tth->sleeper, tth->poll_interval, EINA_TRUE);
      }
 }
 
@@ -361,26 +323,16 @@ temperature_face_update_config(Config_Face *inst)
 
    tth = calloc(1, sizeof(Tempthread));
    tth->poll_interval = inst->poll_interval;
-   tth->sensor_type = inst->sensor_type;
    tth->inst = inst;
    tth->sleeper = e_powersave_sleeper_new();
    if (inst->sensor_name)
      tth->sensor_name = eina_stringshare_add(inst->sensor_name);
 
-#ifdef HAVE_EEZE
-   if (inst->backend != TEMPGET)
-     {
-        inst->poller = ecore_poller_add(ECORE_POLLER_CORE, inst->poll_interval,
-                                        _temperature_udev_poll, tth);
-        inst->tth = tth;
-     }
-   else
-#endif
-     inst->th = ecore_thread_feedback_run(_temperature_check_main,
-                                          _temperature_check_notify,
-                                          _temperature_check_done,
-                                          _temperature_check_done,
-                                          tth, EINA_TRUE);
+   inst->th = ecore_thread_feedback_run(_temperature_check_main,
+                                        _temperature_check_notify,
+                                        _temperature_check_done,
+                                        _temperature_check_done,
+                                        tth, EINA_TRUE);
 }
 
 /* module setup */
@@ -402,10 +354,6 @@ e_modapi_init(E_Module *m)
    E_CONFIG_VAL(D, T, poll_interval, INT);
    E_CONFIG_VAL(D, T, low, INT);
    E_CONFIG_VAL(D, T, high, INT);
-   E_CONFIG_VAL(D, T, sensor_type, INT);
-#ifdef HAVE_EEZE
-   E_CONFIG_VAL(D, T, backend, INT);
-#endif
    E_CONFIG_VAL(D, T, sensor_name, STR);
    E_CONFIG_VAL(D, T, units, INT);
 
@@ -423,6 +371,7 @@ e_modapi_init(E_Module *m)
      eina_hash_foreach(temperature_config->faces, _temperature_face_id_max, &uuid);
    temperature_config->module = m;
 
+   temperature_tempget_setup();
    e_gadcon_provider_register(&_gadcon_class);
    return m;
 }
@@ -434,6 +383,7 @@ e_modapi_shutdown(E_Module *m EINA_UNUSED)
    if (temperature_config->faces)
      eina_hash_foreach(temperature_config->faces, _temperature_face_shutdown, NULL);
    eina_hash_free(temperature_config->faces);
+   temperature_tempget_clear();
    free(temperature_config);
    temperature_config = NULL;
    E_CONFIG_DD_FREE(conf_face_edd);
